=========
ColabHost
=========


.. image:: https://img.shields.io/pypi/v/colab_host.svg
        :target: https://pypi.python.org/pypi/colab_host

.. image:: https://img.shields.io/travis/PuneethaPai/colab_host.svg
        :target: https://travis-ci.com/PuneethaPai/colab_host

.. image:: https://readthedocs.org/projects/colab-host/badge/?version=latest
        :target: https://colab-host.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black



Host any python application in colab environment..


* Free software: MIT license
* Documentation: https://colab-host.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
